==> powerbi-visuals-0.5.3.tgz: package/lib/VisualsContracts.nonmin.js <==
!function(modules) {
    function __webpack_require__(moduleId) {
        if (installedModules[moduleId]) return installedModules[moduleId].exports;
        var module = installedModules[moduleId] = {
            exports: {},
            id: moduleId,
            loaded: !1
        };
        return modules[moduleId].call(module.exports, module, module.exports, __webpack_require__), 
        module.loaded = !0, module.exports;
    }
    var installedModules = {};
    return __webpack_require__.m = modules, __webpack_require__.c = installedModules, 
    __webpack_require__.p = "", __webpack_require__(0);
}({
    0: function(module, exports, __webpack_require__) {
        module.exports = __webpack_require__(298);
    },
    298: function(module, exports, __webpack_require__) {
        window.jsCommon, window.powerbi, window.powerbitests, window.InJs, window.debug, 
        window.jasmine, window.Microsoft;
        window.jsCommon = window.jsCommon || {}, window.powerbi = window.powerbi || {}, 
        window.debug = window.debug || {}, window.InJs = window.InJs || {}, __webpack_require__(299), 
        __webpack_require__(300), __webpack_require__(301), __webpack_require__(302), __webpack_require__(303), 
        __webpack_require__(304), __webpack_require__(305), __webpack_require__(306), __webpack_require__(307), 
        __webpack_require__(308), __webpack_require__(309), __webpack_require__(310), __webpack_require__(311), 
        __webpack_require__(312), __webpack_require__(313), __webpack_require__(314), __webpack_require__(315), 
        __webpack_require__(316), __webpack_require__(317), __webpack_require__(318), __webpack_require__(319), 
        __webpack_require__(320), __webpack_require__(321), __webpack_require__(322), __webpack_require__(323), 
        __webpack_require__(324), __webpack_require__(325), __webpack_require__(326), __webpack_require__(327), 
        __webpack_require__(328), __webpack_require__(329), __webpack_require__(330), __webpack_require__(331), 
        __webpack_require__(332), __webpack_require__(333), __webpack_require__(334), __webpack_require__(335), 
        __webpack_require__(336), __webpack_require__(337), __webpack_require__(338), __webpack_require__(339), 
        __webpack_require__(340), __webpack_require__(341), __webpack_require__(342), __webpack_require__(343), 
        __webpack_require__(344), __webpack_require__(345);
    },
    299: function(module, exports) {
        window.jsCommon, window.powerbi, window.powerbitests, window.InJs, window.debug, 
        window.jasmine, window.Microsoft;
    },
    300: function(module, exports) {
        var powerbi, powerbi = (window.jsCommon, window.powerbi);
        window.powerbitests, window.InJs, window.debug, window.jasmine, window.Microsoft;
        !function(powerbi) {
            !function(VisualDataRoleKind) {
                VisualDataRoleKind[VisualDataRoleKind.Grouping = 0] = "Grouping", VisualDataRoleKind[VisualDataRoleKind.Measure = 1] = "Measure", 
                VisualDataRoleKind[VisualDataRoleKind.GroupingOrMeasure = 2] = "GroupingOrMeasure";
            }(powerbi.VisualDataRoleKind || (powerbi.VisualDataRoleKind = {}));
            powerbi.VisualDataRoleKind;
            !function(VisualDataChangeOperationKind) {
                VisualDataChangeOperationKind[VisualDataChangeOperationKind.Create = 0] = "Create", 
                VisualDataChangeOperationKind[VisualDataChangeOperationKind.Append = 1] = "Append";
            }(powerbi.VisualDataChangeOperationKind || (powerbi.VisualDataChangeOperationKind = {}));
            powerbi.VisualDataChangeOperationKind;
            !function(VisualUpdateType) {
                VisualUpdateType[VisualUpdateType.Data = 2] = "Data", VisualUpdateType[VisualUpdateType.Resize = 4] = "Resize", 
                VisualUpdateType[VisualUpdateType.ViewMode = 8] = "ViewMode", VisualUpdateType[VisualUpdateType.Style = 16] = "Style", 
                VisualUpdateType[VisualUpdateType.ResizeEnd = 32] = "ResizeEnd", VisualUpdateType[VisualUpdateType.All = 62] = "All";
            }(powerbi.VisualUpdateType || (powerbi.VisualUpdateType = {}));
            powerbi.VisualUpdateType;
            !function(VisualPermissions) {}(powerbi.VisualPermissions || (powerbi.VisualPermissions = {}));
            var visuals;
            powerbi.VisualPermissions;
            !function(visuals) {
                var telemetry;
                !function(telemetry) {
                    !function(ErrorSource) {
                        ErrorSource[ErrorSource.PowerBI = 0] = "PowerBI", ErrorSource[ErrorSource.External = 1] = "External", 
                        ErrorSource[ErrorSource.User = 2] = "User";
                    }(telemetry.ErrorSource || (telemetry.ErrorSource = {}));
                    telemetry.ErrorSource;
                }(telemetry = visuals.telemetry || (visuals.telemetry = {}));
            }(visuals = powerbi.visuals || (powerbi.visuals = {}));
        }(powerbi || (powerbi = {}));
    },
    301: function(module, exports) {},
    302: function(module, exports) {},
    303: function(module, exports) {},
    304: function(module, exports) {},
    305: function(module, exports) {},
    306: function(module, exports) {},
    307: function(module, exports) {},
    308: function(module, exports) {},
    309: function(module, exports) {},
    310: function(module, exports) {},
    311: function(module, exports) {},
    312: function(module, exports) {},
    313: function(module, exports) {},
    314: function(module, exports) {},
    315: function(module, exports) {},
    316: function(module, exports) {},
    317: function(module, exports) {},
    318: function(module, exports) {},
    319: function(module, exports) {},
    320: function(module, exports) {},
    321: function(module, exports) {},
    322: function(module, exports) {},
    323: function(module, exports) {},
    324: function(module, exports) {},
    325: function(module, exports) {},
    326: function(module, exports) {},
    327: function(module, exports) {},
    328: function(module, exports) {},
    329: function(module, exports) {},
    330: function(module, exports) {},
    331: function(module, exports) {},
    332: function(module, exports) {},
    333: function(module, exports) {},
    334: function(module, exports) {},
    335: function(module, exports) {},
    336: function(module, exports) {},
    337: function(module, exports) {},
    338: function(module, exports) {},
    339: function(module, exports) {},
    340: function(module, exports) {},
    341: function(module, exports) {},
    342: function(module, exports) {},
    343: function(module, exports) {},
    344: function(module, exports) {},
    345: function(module, exports) {}
});

==> powerbi-visuals-0.5.9.tgz: package/lib/VisualsContracts.nonmin.js <==
!function(modules) {
    function __webpack_require__(moduleId) {
        if (installedModules[moduleId]) return installedModules[moduleId].exports;
        var module = installedModules[moduleId] = {
            exports: {},
            id: moduleId,
            loaded: !1
        };
        return modules[moduleId].call(module.exports, module, module.exports, __webpack_require__), 
        module.loaded = !0, module.exports;
    }
    var installedModules = {};
    return __webpack_require__.m = modules, __webpack_require__.c = installedModules, 
    __webpack_require__.p = "", __webpack_require__(0);
}({
    0: function(module, exports, __webpack_require__) {
        module.exports = __webpack_require__(324);
    },
    324: function(module, exports, __webpack_require__) {
        window.jsCommon, window.powerbi, window.powerbitests, window.InJs, window.debug, 
        window.jasmine, window.Microsoft;
        window.jsCommon = window.jsCommon || {}, window.powerbi = window.powerbi || {}, 
        window.debug = window.debug || {}, window.InJs = window.InJs || {}, __webpack_require__(325), 
        __webpack_require__(328), __webpack_require__(329), __webpack_require__(330), __webpack_require__(331), 
        __webpack_require__(332), __webpack_require__(333), __webpack_require__(334), __webpack_require__(335), 
        __webpack_require__(336), __webpack_require__(337), __webpack_require__(338), __webpack_require__(339), 
        __webpack_require__(340), __webpack_require__(341), __webpack_require__(342), __webpack_require__(343), 
        __webpack_require__(344), __webpack_require__(345), __webpack_require__(346), __webpack_require__(347), 
        __webpack_require__(348), __webpack_require__(349), __webpack_require__(350), __webpack_require__(351), 
        __webpack_require__(352), __webpack_require__(353), __webpack_require__(354), __webpack_require__(355), 
        __webpack_require__(356), __webpack_require__(357), __webpack_require__(358), __webpack_require__(359), 
        __webpack_require__(360), __webpack_require__(361), __webpack_require__(362), __webpack_require__(363), 
        __webpack_require__(364), __webpack_require__(365), __webpack_require__(366), __webpack_require__(367), 
        __webpack_require__(368), __webpack_require__(369), __webpack_require__(370), __webpack_require__(371), 
        __webpack_require__(372);
    },
    325: function(module, exports, __webpack_require__) {
        window.jsCommon, window.powerbi, window.powerbitests, window.InJs, window.debug, 
        window.jasmine, window.Microsoft;
        __webpack_require__(326), __webpack_require__(327);
    },
    326: function(module, exports) {
        window.jsCommon, window.powerbi, window.powerbitests, window.InJs, window.debug, 
        window.jasmine, window.Microsoft;
    },
    327: function(module, exports) {
        var powerbi, powerbi = (window.jsCommon, window.powerbi);
        window.powerbitests, window.InJs, window.debug, window.jasmine, window.Microsoft;
        !function(powerbi) {
            !function(VisualDataRoleKind) {
                VisualDataRoleKind[VisualDataRoleKind.Grouping = 0] = "Grouping", VisualDataRoleKind[VisualDataRoleKind.Measure = 1] = "Measure", 
                VisualDataRoleKind[VisualDataRoleKind.GroupingOrMeasure = 2] = "GroupingOrMeasure";
            }(powerbi.VisualDataRoleKind || (powerbi.VisualDataRoleKind = {}));
            powerbi.VisualDataRoleKind;
            !function(VisualDataChangeOperationKind) {
                VisualDataChangeOperationKind[VisualDataChangeOperationKind.Create = 0] = "Create", 
                VisualDataChangeOperationKind[VisualDataChangeOperationKind.Append = 1] = "Append";
            }(powerbi.VisualDataChangeOperationKind || (powerbi.VisualDataChangeOperationKind = {}));
            powerbi.VisualDataChangeOperationKind;
            !function(VisualUpdateType) {
                VisualUpdateType[VisualUpdateType.Data = 2] = "Data", VisualUpdateType[VisualUpdateType.Resize = 4] = "Resize", 
                VisualUpdateType[VisualUpdateType.ViewMode = 8] = "ViewMode", VisualUpdateType[VisualUpdateType.Style = 16] = "Style", 
                VisualUpdateType[VisualUpdateType.ResizeEnd = 32] = "ResizeEnd", VisualUpdateType[VisualUpdateType.All = 62] = "All";
            }(powerbi.VisualUpdateType || (powerbi.VisualUpdateType = {}));
            powerbi.VisualUpdateType;
            !function(VisualPermissions) {}(powerbi.VisualPermissions || (powerbi.VisualPermissions = {}));
            var visuals;
            powerbi.VisualPermissions;
            !function(visuals) {
                var telemetry;
                !function(telemetry) {
                    !function(ErrorSource) {
                        ErrorSource[ErrorSource.PowerBI = 0] = "PowerBI", ErrorSource[ErrorSource.External = 1] = "External", 
                        ErrorSource[ErrorSource.User = 2] = "User";
                    }(telemetry.ErrorSource || (telemetry.ErrorSource = {}));
                    telemetry.ErrorSource;
                }(telemetry = visuals.telemetry || (visuals.telemetry = {}));
            }(visuals = powerbi.visuals || (powerbi.visuals = {}));
        }(powerbi || (powerbi = {}));
    },
    328: function(module, exports) {},
    329: function(module, exports) {},
    330: function(module, exports) {},
    331: function(module, exports) {},
    332: function(module, exports) {},
    333: function(module, exports) {},
    334: function(module, exports) {},
    335: function(module, exports) {},
    336: function(module, exports) {},
    337: function(module, exports) {},
    338: function(module, exports) {},
    339: function(module, exports) {},
    340: function(module, exports) {},
    341: function(module, exports) {},
    342: function(module, exports) {},
    343: function(module, exports) {},
    344: function(module, exports) {},
    345: function(module, exports) {},
    346: function(module, exports) {},
    347: function(module, exports) {},
    348: function(module, exports) {},
    349: function(module, exports) {},
    350: function(module, exports) {},
    351: function(module, exports) {},
    352: function(module, exports) {},
    353: function(module, exports) {},
    354: function(module, exports) {},
    355: function(module, exports) {},
    356: function(module, exports) {},
    357: function(module, exports) {},
    358: function(module, exports) {},
    359: function(module, exports) {},
    360: function(module, exports) {},
    361: function(module, exports) {},
    362: function(module, exports) {},
    363: function(module, exports) {},
    364: function(module, exports) {},
    365: function(module, exports) {},
    366: function(module, exports) {},
    367: function(module, exports) {},
    368: function(module, exports) {},
    369: function(module, exports) {},
    370: function(module, exports) {},
    371: function(module, exports) {},
    372: function(module, exports) {}
});
